# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PublicHolidayOccurrence(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'english_name': 'str',
        'local_name': 'str',
        'occurrence_date': 'datetime',
        'holiday_type': 'str',
        'nationwaide': 'bool'
    }

    attribute_map = {
        'english_name': 'EnglishName',
        'local_name': 'LocalName',
        'occurrence_date': 'OccurrenceDate',
        'holiday_type': 'HolidayType',
        'nationwaide': 'Nationwaide'
    }

    def __init__(self, english_name=None, local_name=None, occurrence_date=None, holiday_type=None, nationwaide=None):  # noqa: E501
        """PublicHolidayOccurrence - a model defined in Swagger"""  # noqa: E501

        self._english_name = None
        self._local_name = None
        self._occurrence_date = None
        self._holiday_type = None
        self._nationwaide = None
        self.discriminator = None

        if english_name is not None:
            self.english_name = english_name
        if local_name is not None:
            self.local_name = local_name
        if occurrence_date is not None:
            self.occurrence_date = occurrence_date
        if holiday_type is not None:
            self.holiday_type = holiday_type
        if nationwaide is not None:
            self.nationwaide = nationwaide

    @property
    def english_name(self):
        """Gets the english_name of this PublicHolidayOccurrence.  # noqa: E501

        Name of the holiday in English  # noqa: E501

        :return: The english_name of this PublicHolidayOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._english_name

    @english_name.setter
    def english_name(self, english_name):
        """Sets the english_name of this PublicHolidayOccurrence.

        Name of the holiday in English  # noqa: E501

        :param english_name: The english_name of this PublicHolidayOccurrence.  # noqa: E501
        :type: str
        """

        self._english_name = english_name

    @property
    def local_name(self):
        """Gets the local_name of this PublicHolidayOccurrence.  # noqa: E501

        Local name of the holiday  # noqa: E501

        :return: The local_name of this PublicHolidayOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._local_name

    @local_name.setter
    def local_name(self, local_name):
        """Sets the local_name of this PublicHolidayOccurrence.

        Local name of the holiday  # noqa: E501

        :param local_name: The local_name of this PublicHolidayOccurrence.  # noqa: E501
        :type: str
        """

        self._local_name = local_name

    @property
    def occurrence_date(self):
        """Gets the occurrence_date of this PublicHolidayOccurrence.  # noqa: E501

        Date of the holiday (start time)  # noqa: E501

        :return: The occurrence_date of this PublicHolidayOccurrence.  # noqa: E501
        :rtype: datetime
        """
        return self._occurrence_date

    @occurrence_date.setter
    def occurrence_date(self, occurrence_date):
        """Sets the occurrence_date of this PublicHolidayOccurrence.

        Date of the holiday (start time)  # noqa: E501

        :param occurrence_date: The occurrence_date of this PublicHolidayOccurrence.  # noqa: E501
        :type: datetime
        """

        self._occurrence_date = occurrence_date

    @property
    def holiday_type(self):
        """Gets the holiday_type of this PublicHolidayOccurrence.  # noqa: E501

        Type of the holiday; possible values are: Public, Bank, School, Authorities, Optional, Observance  # noqa: E501

        :return: The holiday_type of this PublicHolidayOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._holiday_type

    @holiday_type.setter
    def holiday_type(self, holiday_type):
        """Sets the holiday_type of this PublicHolidayOccurrence.

        Type of the holiday; possible values are: Public, Bank, School, Authorities, Optional, Observance  # noqa: E501

        :param holiday_type: The holiday_type of this PublicHolidayOccurrence.  # noqa: E501
        :type: str
        """

        self._holiday_type = holiday_type

    @property
    def nationwaide(self):
        """Gets the nationwaide of this PublicHolidayOccurrence.  # noqa: E501

        True if the holiday is celebrated in all locales in the country, false otherwise  # noqa: E501

        :return: The nationwaide of this PublicHolidayOccurrence.  # noqa: E501
        :rtype: bool
        """
        return self._nationwaide

    @nationwaide.setter
    def nationwaide(self, nationwaide):
        """Sets the nationwaide of this PublicHolidayOccurrence.

        True if the holiday is celebrated in all locales in the country, false otherwise  # noqa: E501

        :param nationwaide: The nationwaide of this PublicHolidayOccurrence.  # noqa: E501
        :type: bool
        """

        self._nationwaide = nationwaide

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PublicHolidayOccurrence, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicHolidayOccurrence):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WhoisResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'valid_domain': 'bool',
        'registrant_name': 'str',
        'registrant_organization': 'str',
        'registrant_email': 'str',
        'registrant_street_number': 'str',
        'registrant_street': 'str',
        'registrant_city': 'str',
        'registrant_state_or_province': 'str',
        'registrant_postal_code': 'str',
        'registrant_country': 'str',
        'registrant_raw_address': 'str',
        'registrant_telephone': 'str',
        'whois_server': 'str',
        'raw_text_record': 'str',
        'created_dt': 'datetime'
    }

    attribute_map = {
        'valid_domain': 'ValidDomain',
        'registrant_name': 'RegistrantName',
        'registrant_organization': 'RegistrantOrganization',
        'registrant_email': 'RegistrantEmail',
        'registrant_street_number': 'RegistrantStreetNumber',
        'registrant_street': 'RegistrantStreet',
        'registrant_city': 'RegistrantCity',
        'registrant_state_or_province': 'RegistrantStateOrProvince',
        'registrant_postal_code': 'RegistrantPostalCode',
        'registrant_country': 'RegistrantCountry',
        'registrant_raw_address': 'RegistrantRawAddress',
        'registrant_telephone': 'RegistrantTelephone',
        'whois_server': 'WhoisServer',
        'raw_text_record': 'RawTextRecord',
        'created_dt': 'CreatedDt'
    }

    def __init__(self, valid_domain=None, registrant_name=None, registrant_organization=None, registrant_email=None, registrant_street_number=None, registrant_street=None, registrant_city=None, registrant_state_or_province=None, registrant_postal_code=None, registrant_country=None, registrant_raw_address=None, registrant_telephone=None, whois_server=None, raw_text_record=None, created_dt=None):  # noqa: E501
        """WhoisResponse - a model defined in Swagger"""  # noqa: E501

        self._valid_domain = None
        self._registrant_name = None
        self._registrant_organization = None
        self._registrant_email = None
        self._registrant_street_number = None
        self._registrant_street = None
        self._registrant_city = None
        self._registrant_state_or_province = None
        self._registrant_postal_code = None
        self._registrant_country = None
        self._registrant_raw_address = None
        self._registrant_telephone = None
        self._whois_server = None
        self._raw_text_record = None
        self._created_dt = None
        self.discriminator = None

        if valid_domain is not None:
            self.valid_domain = valid_domain
        if registrant_name is not None:
            self.registrant_name = registrant_name
        if registrant_organization is not None:
            self.registrant_organization = registrant_organization
        if registrant_email is not None:
            self.registrant_email = registrant_email
        if registrant_street_number is not None:
            self.registrant_street_number = registrant_street_number
        if registrant_street is not None:
            self.registrant_street = registrant_street
        if registrant_city is not None:
            self.registrant_city = registrant_city
        if registrant_state_or_province is not None:
            self.registrant_state_or_province = registrant_state_or_province
        if registrant_postal_code is not None:
            self.registrant_postal_code = registrant_postal_code
        if registrant_country is not None:
            self.registrant_country = registrant_country
        if registrant_raw_address is not None:
            self.registrant_raw_address = registrant_raw_address
        if registrant_telephone is not None:
            self.registrant_telephone = registrant_telephone
        if whois_server is not None:
            self.whois_server = whois_server
        if raw_text_record is not None:
            self.raw_text_record = raw_text_record
        if created_dt is not None:
            self.created_dt = created_dt

    @property
    def valid_domain(self):
        """Gets the valid_domain of this WhoisResponse.  # noqa: E501

        True if the domain is valid, false if it is not  # noqa: E501

        :return: The valid_domain of this WhoisResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_domain

    @valid_domain.setter
    def valid_domain(self, valid_domain):
        """Sets the valid_domain of this WhoisResponse.

        True if the domain is valid, false if it is not  # noqa: E501

        :param valid_domain: The valid_domain of this WhoisResponse.  # noqa: E501
        :type: bool
        """

        self._valid_domain = valid_domain

    @property
    def registrant_name(self):
        """Gets the registrant_name of this WhoisResponse.  # noqa: E501

        Name of the domain registrant  # noqa: E501

        :return: The registrant_name of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_name

    @registrant_name.setter
    def registrant_name(self, registrant_name):
        """Sets the registrant_name of this WhoisResponse.

        Name of the domain registrant  # noqa: E501

        :param registrant_name: The registrant_name of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_name = registrant_name

    @property
    def registrant_organization(self):
        """Gets the registrant_organization of this WhoisResponse.  # noqa: E501

        Organization name of the domain registrant  # noqa: E501

        :return: The registrant_organization of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_organization

    @registrant_organization.setter
    def registrant_organization(self, registrant_organization):
        """Sets the registrant_organization of this WhoisResponse.

        Organization name of the domain registrant  # noqa: E501

        :param registrant_organization: The registrant_organization of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_organization = registrant_organization

    @property
    def registrant_email(self):
        """Gets the registrant_email of this WhoisResponse.  # noqa: E501

        Email address of the domain registrant  # noqa: E501

        :return: The registrant_email of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_email

    @registrant_email.setter
    def registrant_email(self, registrant_email):
        """Sets the registrant_email of this WhoisResponse.

        Email address of the domain registrant  # noqa: E501

        :param registrant_email: The registrant_email of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_email = registrant_email

    @property
    def registrant_street_number(self):
        """Gets the registrant_street_number of this WhoisResponse.  # noqa: E501

        Street number of the address of the domain registrant, if available  # noqa: E501

        :return: The registrant_street_number of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_street_number

    @registrant_street_number.setter
    def registrant_street_number(self, registrant_street_number):
        """Sets the registrant_street_number of this WhoisResponse.

        Street number of the address of the domain registrant, if available  # noqa: E501

        :param registrant_street_number: The registrant_street_number of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_street_number = registrant_street_number

    @property
    def registrant_street(self):
        """Gets the registrant_street of this WhoisResponse.  # noqa: E501

        Street name of the address of the domain registrant, if available  # noqa: E501

        :return: The registrant_street of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_street

    @registrant_street.setter
    def registrant_street(self, registrant_street):
        """Sets the registrant_street of this WhoisResponse.

        Street name of the address of the domain registrant, if available  # noqa: E501

        :param registrant_street: The registrant_street of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_street = registrant_street

    @property
    def registrant_city(self):
        """Gets the registrant_city of this WhoisResponse.  # noqa: E501

        City of the domain registrant, if available  # noqa: E501

        :return: The registrant_city of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_city

    @registrant_city.setter
    def registrant_city(self, registrant_city):
        """Sets the registrant_city of this WhoisResponse.

        City of the domain registrant, if available  # noqa: E501

        :param registrant_city: The registrant_city of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_city = registrant_city

    @property
    def registrant_state_or_province(self):
        """Gets the registrant_state_or_province of this WhoisResponse.  # noqa: E501

        State or Province of the address of the domain registrant, if available  # noqa: E501

        :return: The registrant_state_or_province of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_state_or_province

    @registrant_state_or_province.setter
    def registrant_state_or_province(self, registrant_state_or_province):
        """Sets the registrant_state_or_province of this WhoisResponse.

        State or Province of the address of the domain registrant, if available  # noqa: E501

        :param registrant_state_or_province: The registrant_state_or_province of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_state_or_province = registrant_state_or_province

    @property
    def registrant_postal_code(self):
        """Gets the registrant_postal_code of this WhoisResponse.  # noqa: E501

        Postal code of the address of the domain registrant, if available  # noqa: E501

        :return: The registrant_postal_code of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_postal_code

    @registrant_postal_code.setter
    def registrant_postal_code(self, registrant_postal_code):
        """Sets the registrant_postal_code of this WhoisResponse.

        Postal code of the address of the domain registrant, if available  # noqa: E501

        :param registrant_postal_code: The registrant_postal_code of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_postal_code = registrant_postal_code

    @property
    def registrant_country(self):
        """Gets the registrant_country of this WhoisResponse.  # noqa: E501

        Country of the address of the domain registrant, if available  # noqa: E501

        :return: The registrant_country of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_country

    @registrant_country.setter
    def registrant_country(self, registrant_country):
        """Sets the registrant_country of this WhoisResponse.

        Country of the address of the domain registrant, if available  # noqa: E501

        :param registrant_country: The registrant_country of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_country = registrant_country

    @property
    def registrant_raw_address(self):
        """Gets the registrant_raw_address of this WhoisResponse.  # noqa: E501

        Raw address string of the domain registrant, if available  # noqa: E501

        :return: The registrant_raw_address of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_raw_address

    @registrant_raw_address.setter
    def registrant_raw_address(self, registrant_raw_address):
        """Sets the registrant_raw_address of this WhoisResponse.

        Raw address string of the domain registrant, if available  # noqa: E501

        :param registrant_raw_address: The registrant_raw_address of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_raw_address = registrant_raw_address

    @property
    def registrant_telephone(self):
        """Gets the registrant_telephone of this WhoisResponse.  # noqa: E501

        Telephone number of the address of the domain registrant  # noqa: E501

        :return: The registrant_telephone of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._registrant_telephone

    @registrant_telephone.setter
    def registrant_telephone(self, registrant_telephone):
        """Sets the registrant_telephone of this WhoisResponse.

        Telephone number of the address of the domain registrant  # noqa: E501

        :param registrant_telephone: The registrant_telephone of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._registrant_telephone = registrant_telephone

    @property
    def whois_server(self):
        """Gets the whois_server of this WhoisResponse.  # noqa: E501

        Server used to lookup WHOIS information (may change based on lookup).  # noqa: E501

        :return: The whois_server of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._whois_server

    @whois_server.setter
    def whois_server(self, whois_server):
        """Sets the whois_server of this WhoisResponse.

        Server used to lookup WHOIS information (may change based on lookup).  # noqa: E501

        :param whois_server: The whois_server of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._whois_server = whois_server

    @property
    def raw_text_record(self):
        """Gets the raw_text_record of this WhoisResponse.  # noqa: E501

        WHOIS raw text record  # noqa: E501

        :return: The raw_text_record of this WhoisResponse.  # noqa: E501
        :rtype: str
        """
        return self._raw_text_record

    @raw_text_record.setter
    def raw_text_record(self, raw_text_record):
        """Sets the raw_text_record of this WhoisResponse.

        WHOIS raw text record  # noqa: E501

        :param raw_text_record: The raw_text_record of this WhoisResponse.  # noqa: E501
        :type: str
        """

        self._raw_text_record = raw_text_record

    @property
    def created_dt(self):
        """Gets the created_dt of this WhoisResponse.  # noqa: E501

        Creation date for the record  # noqa: E501

        :return: The created_dt of this WhoisResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this WhoisResponse.

        Creation date for the record  # noqa: E501

        :param created_dt: The created_dt of this WhoisResponse.  # noqa: E501
        :type: datetime
        """

        self._created_dt = created_dt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WhoisResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WhoisResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_validate_api_client
from cloudmersive_validate_api_client.models.sql_injection_detection_result import SqlInjectionDetectionResult  # noqa: E501
from cloudmersive_validate_api_client.rest import ApiException


class TestSqlInjectionDetectionResult(unittest.TestCase):
    """SqlInjectionDetectionResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSqlInjectionDetectionResult(self):
        """Test SqlInjectionDetectionResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cloudmersive_validate_api_client.models.sql_injection_detection_result.SqlInjectionDetectionResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class VatApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def vat_vat_lookup(self, input, **kwargs):  # noqa: E501
        """Validate a VAT number  # noqa: E501

        Checks if a VAT code is valid, and if it is, returns more information about it.  The first two letters of the VAT number must be letters that indicate the country, such as LU20260743.  Possible country codes include Austria (AT), Belgium (BE), Bulgaria (BG), Cyprus (CY), Czech Republic (CZ), Germany (DE), Denmark (DK), Estonia (EE), Greece (EL), Spain (ES), Finland (FI), France (FR), United Kingdom (GB), Croatia (HR), Hungary (HU), Ireland (IE), Italy (IT), Lithuania (LT), Luxembourg (LU), Latvia (LV), Malta (MT), The Netherlands (NL), Poland (PL), Portugal (PT), Romania (RO), Sweden (SE), Slovenia (SI), Slovakia (SK).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.vat_vat_lookup(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param VatLookupRequest input: Input VAT code (required)
        :return: VatLookupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.vat_vat_lookup_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.vat_vat_lookup_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def vat_vat_lookup_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a VAT number  # noqa: E501

        Checks if a VAT code is valid, and if it is, returns more information about it.  The first two letters of the VAT number must be letters that indicate the country, such as LU20260743.  Possible country codes include Austria (AT), Belgium (BE), Bulgaria (BG), Cyprus (CY), Czech Republic (CZ), Germany (DE), Denmark (DK), Estonia (EE), Greece (EL), Spain (ES), Finland (FI), France (FR), United Kingdom (GB), Croatia (HR), Hungary (HU), Ireland (IE), Italy (IT), Lithuania (LT), Luxembourg (LU), Latvia (LV), Malta (MT), The Netherlands (NL), Poland (PL), Portugal (PT), Romania (RO), Sweden (SE), Slovenia (SI), Slovakia (SK).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.vat_vat_lookup_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param VatLookupRequest input: Input VAT code (required)
        :return: VatLookupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method vat_vat_lookup" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `vat_vat_lookup`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/vat/lookup', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VatLookupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class DomainApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def domain_check(self, domain, **kwargs):  # noqa: E501
        """Validate a domain name  # noqa: E501

        Check whether a domain name is valid or not.  API performs a live validation by contacting DNS services to validate the existence of the domain name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_check(domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain: Domain name to check, for example \"cloudmersive.com\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: CheckResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_check_with_http_info(domain, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_check_with_http_info(domain, **kwargs)  # noqa: E501
            return data

    def domain_check_with_http_info(self, domain, **kwargs):  # noqa: E501
        """Validate a domain name  # noqa: E501

        Check whether a domain name is valid or not.  API performs a live validation by contacting DNS services to validate the existence of the domain name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_check_with_http_info(domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain: Domain name to check, for example \"cloudmersive.com\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: CheckResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain' is set
        if ('domain' not in params or
                params['domain'] is None):
            raise ValueError("Missing the required parameter `domain` when calling `domain_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'domain' in params:
            body_params = params['domain']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_get_top_level_domain_from_url(self, request, **kwargs):  # noqa: E501
        """Get top-level domain name from URL  # noqa: E501

        Gets the top-level domain name from a URL, such as mydomain.com.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_get_top_level_domain_from_url(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateUrlRequestSyntaxOnly request: Input URL information (required)
        :return: ValidateUrlResponseSyntaxOnly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_get_top_level_domain_from_url_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_get_top_level_domain_from_url_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_get_top_level_domain_from_url_with_http_info(self, request, **kwargs):  # noqa: E501
        """Get top-level domain name from URL  # noqa: E501

        Gets the top-level domain name from a URL, such as mydomain.com.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_get_top_level_domain_from_url_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateUrlRequestSyntaxOnly request: Input URL information (required)
        :return: ValidateUrlResponseSyntaxOnly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_get_top_level_domain_from_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_get_top_level_domain_from_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/get-top-level-domain', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateUrlResponseSyntaxOnly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_phishing_check(self, request, **kwargs):  # noqa: E501
        """Check a URL for Phishing threats  # noqa: E501

        Checks if an input URL is at risk of being an Phishing (fake login page, or other page designed to collect information via social engineering) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_phishing_check(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PhishingCheckRequest request: Input URL request (required)
        :return: PhishingCheckResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_phishing_check_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_phishing_check_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_phishing_check_with_http_info(self, request, **kwargs):  # noqa: E501
        """Check a URL for Phishing threats  # noqa: E501

        Checks if an input URL is at risk of being an Phishing (fake login page, or other page designed to collect information via social engineering) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_phishing_check_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PhishingCheckRequest request: Input URL request (required)
        :return: PhishingCheckResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_phishing_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_phishing_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/phishing-threat-check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PhishingCheckResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_post(self, domain, **kwargs):  # noqa: E501
        """Get WHOIS information for a domain  # noqa: E501

        Validate whether a domain name exists, and also return the full WHOIS record for that domain name.  WHOIS records include all the registration details of the domain name, such as information about the domain's owners.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_post(domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain: Domain name to check, for example \"cloudmersive.com\".   The input is a string so be sure to enclose it in double-quotes. (required)
        :return: WhoisResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_post_with_http_info(domain, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_post_with_http_info(domain, **kwargs)  # noqa: E501
            return data

    def domain_post_with_http_info(self, domain, **kwargs):  # noqa: E501
        """Get WHOIS information for a domain  # noqa: E501

        Validate whether a domain name exists, and also return the full WHOIS record for that domain name.  WHOIS records include all the registration details of the domain name, such as information about the domain's owners.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_post_with_http_info(domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain: Domain name to check, for example \"cloudmersive.com\".   The input is a string so be sure to enclose it in double-quotes. (required)
        :return: WhoisResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain' is set
        if ('domain' not in params or
                params['domain'] is None):
            raise ValueError("Missing the required parameter `domain` when calling `domain_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'domain' in params:
            body_params = params['domain']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/whois', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WhoisResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_quality_score(self, domain, **kwargs):  # noqa: E501
        """Validate a domain name's quality score  # noqa: E501

        Check the quality of a domain name.  Supports over 9 million domain names.  Higher quality scores indicate more trust and authority in the domain name, with values ranging from 0.0 (low quality) to 10.0 (maximum quality).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_quality_score(domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain: Domain name to check, for example \"cloudmersive.com\". (required)
        :return: DomainQualityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_quality_score_with_http_info(domain, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_quality_score_with_http_info(domain, **kwargs)  # noqa: E501
            return data

    def domain_quality_score_with_http_info(self, domain, **kwargs):  # noqa: E501
        """Validate a domain name's quality score  # noqa: E501

        Check the quality of a domain name.  Supports over 9 million domain names.  Higher quality scores indicate more trust and authority in the domain name, with values ranging from 0.0 (low quality) to 10.0 (maximum quality).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_quality_score_with_http_info(domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain: Domain name to check, for example \"cloudmersive.com\". (required)
        :return: DomainQualityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_quality_score" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain' is set
        if ('domain' not in params or
                params['domain'] is None):
            raise ValueError("Missing the required parameter `domain` when calling `domain_quality_score`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'domain' in params:
            body_params = params['domain']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/quality-score', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainQualityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_safety_check(self, request, **kwargs):  # noqa: E501
        """Check a URL for safety threats  # noqa: E501

        Checks if an input URL is at risk of being a safety threat through malware, unwanted software, or social engineering threats.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_safety_check(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSafetyCheckRequestFull request: Input URL request (required)
        :return: UrlSafetyCheckResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_safety_check_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_safety_check_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_safety_check_with_http_info(self, request, **kwargs):  # noqa: E501
        """Check a URL for safety threats  # noqa: E501

        Checks if an input URL is at risk of being a safety threat through malware, unwanted software, or social engineering threats.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_safety_check_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSafetyCheckRequestFull request: Input URL request (required)
        :return: UrlSafetyCheckResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_safety_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_safety_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/safety-threat-check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UrlSafetyCheckResponseFull',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_ssrf_check(self, request, **kwargs):  # noqa: E501
        """Check a URL for SSRF threats  # noqa: E501

        Checks if an input URL is at risk of being an SSRF (Server-side request forgery) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_ssrf_check(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSsrfRequestFull request: Input URL request (required)
        :return: UrlSsrfResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_ssrf_check_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_ssrf_check_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_ssrf_check_with_http_info(self, request, **kwargs):  # noqa: E501
        """Check a URL for SSRF threats  # noqa: E501

        Checks if an input URL is at risk of being an SSRF (Server-side request forgery) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_ssrf_check_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSsrfRequestFull request: Input URL request (required)
        :return: UrlSsrfResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_ssrf_check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_ssrf_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/ssrf-threat-check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UrlSsrfResponseFull',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_ssrf_check_batch(self, request, **kwargs):  # noqa: E501
        """Check a URL for SSRF threats in batches  # noqa: E501

        Batch-checks if input URLs are at risk of being an SSRF (Server-side request forgery) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_ssrf_check_batch(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSsrfRequestBatch request: Input URL request as a batch of multiple URLs (required)
        :return: UrlSsrfResponseBatch
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_ssrf_check_batch_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_ssrf_check_batch_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_ssrf_check_batch_with_http_info(self, request, **kwargs):  # noqa: E501
        """Check a URL for SSRF threats in batches  # noqa: E501

        Batch-checks if input URLs are at risk of being an SSRF (Server-side request forgery) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_ssrf_check_batch_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSsrfRequestBatch request: Input URL request as a batch of multiple URLs (required)
        :return: UrlSsrfResponseBatch
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_ssrf_check_batch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_ssrf_check_batch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/ssrf-threat-check/batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UrlSsrfResponseBatch',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_url_full(self, request, **kwargs):  # noqa: E501
        """Validate a URL fully  # noqa: E501

        Validate whether a URL is syntactically valid (does not check endpoint for validity), whether it exists, and whether the endpoint is up and passes virus scan checks.  Accepts various types of input and produces a well-formed URL as output.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_url_full(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateUrlRequestFull request: Input URL request (required)
        :return: ValidateUrlResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_url_full_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_url_full_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_url_full_with_http_info(self, request, **kwargs):  # noqa: E501
        """Validate a URL fully  # noqa: E501

        Validate whether a URL is syntactically valid (does not check endpoint for validity), whether it exists, and whether the endpoint is up and passes virus scan checks.  Accepts various types of input and produces a well-formed URL as output.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_url_full_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateUrlRequestFull request: Input URL request (required)
        :return: ValidateUrlResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_url_full" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_url_full`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/full', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateUrlResponseFull',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def domain_url_syntax_only(self, request, **kwargs):  # noqa: E501
        """Validate a URL syntactically  # noqa: E501

        Validate whether a URL is syntactically valid (does not check endpoint for validity).  Accepts various types of input and produces a well-formed URL as output.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_url_syntax_only(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateUrlRequestSyntaxOnly request: Input URL information (required)
        :return: ValidateUrlResponseSyntaxOnly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.domain_url_syntax_only_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.domain_url_syntax_only_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def domain_url_syntax_only_with_http_info(self, request, **kwargs):  # noqa: E501
        """Validate a URL syntactically  # noqa: E501

        Validate whether a URL is syntactically valid (does not check endpoint for validity).  Accepts various types of input and produces a well-formed URL as output.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.domain_url_syntax_only_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateUrlRequestSyntaxOnly request: Input URL information (required)
        :return: ValidateUrlResponseSyntaxOnly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domain_url_syntax_only" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `domain_url_syntax_only`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/domain/url/syntax-only', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateUrlResponseSyntaxOnly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UserAgentValidateResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'is_bot': 'bool',
        'bot_name': 'str',
        'bot_url': 'str',
        'operating_system': 'str',
        'operating_system_cpu_platform': 'str',
        'operating_system_version': 'str',
        'device_type': 'str',
        'device_brand_name': 'str',
        'device_model': 'str',
        'browser_name': 'str',
        'browser_version': 'str',
        'browser_engine_name': 'str',
        'browser_engine_version': 'str'
    }

    attribute_map = {
        'successful': 'Successful',
        'is_bot': 'IsBot',
        'bot_name': 'BotName',
        'bot_url': 'BotURL',
        'operating_system': 'OperatingSystem',
        'operating_system_cpu_platform': 'OperatingSystemCPUPlatform',
        'operating_system_version': 'OperatingSystemVersion',
        'device_type': 'DeviceType',
        'device_brand_name': 'DeviceBrandName',
        'device_model': 'DeviceModel',
        'browser_name': 'BrowserName',
        'browser_version': 'BrowserVersion',
        'browser_engine_name': 'BrowserEngineName',
        'browser_engine_version': 'BrowserEngineVersion'
    }

    def __init__(self, successful=None, is_bot=None, bot_name=None, bot_url=None, operating_system=None, operating_system_cpu_platform=None, operating_system_version=None, device_type=None, device_brand_name=None, device_model=None, browser_name=None, browser_version=None, browser_engine_name=None, browser_engine_version=None):  # noqa: E501
        """UserAgentValidateResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._is_bot = None
        self._bot_name = None
        self._bot_url = None
        self._operating_system = None
        self._operating_system_cpu_platform = None
        self._operating_system_version = None
        self._device_type = None
        self._device_brand_name = None
        self._device_model = None
        self._browser_name = None
        self._browser_version = None
        self._browser_engine_name = None
        self._browser_engine_version = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if is_bot is not None:
            self.is_bot = is_bot
        if bot_name is not None:
            self.bot_name = bot_name
        if bot_url is not None:
            self.bot_url = bot_url
        if operating_system is not None:
            self.operating_system = operating_system
        if operating_system_cpu_platform is not None:
            self.operating_system_cpu_platform = operating_system_cpu_platform
        if operating_system_version is not None:
            self.operating_system_version = operating_system_version
        if device_type is not None:
            self.device_type = device_type
        if device_brand_name is not None:
            self.device_brand_name = device_brand_name
        if device_model is not None:
            self.device_model = device_model
        if browser_name is not None:
            self.browser_name = browser_name
        if browser_version is not None:
            self.browser_version = browser_version
        if browser_engine_name is not None:
            self.browser_engine_name = browser_engine_name
        if browser_engine_version is not None:
            self.browser_engine_version = browser_engine_version

    @property
    def successful(self):
        """Gets the successful of this UserAgentValidateResponse.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this UserAgentValidateResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this UserAgentValidateResponse.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this UserAgentValidateResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def is_bot(self):
        """Gets the is_bot of this UserAgentValidateResponse.  # noqa: E501

        True if the request is a known robot, false otherwise  # noqa: E501

        :return: The is_bot of this UserAgentValidateResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_bot

    @is_bot.setter
    def is_bot(self, is_bot):
        """Sets the is_bot of this UserAgentValidateResponse.

        True if the request is a known robot, false otherwise  # noqa: E501

        :param is_bot: The is_bot of this UserAgentValidateResponse.  # noqa: E501
        :type: bool
        """

        self._is_bot = is_bot

    @property
    def bot_name(self):
        """Gets the bot_name of this UserAgentValidateResponse.  # noqa: E501

        Optional; name of the robot if the request was from a known robot, otherwise null  # noqa: E501

        :return: The bot_name of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._bot_name

    @bot_name.setter
    def bot_name(self, bot_name):
        """Sets the bot_name of this UserAgentValidateResponse.

        Optional; name of the robot if the request was from a known robot, otherwise null  # noqa: E501

        :param bot_name: The bot_name of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._bot_name = bot_name

    @property
    def bot_url(self):
        """Gets the bot_url of this UserAgentValidateResponse.  # noqa: E501

        Optional; if available, the URL to the robot  # noqa: E501

        :return: The bot_url of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._bot_url

    @bot_url.setter
    def bot_url(self, bot_url):
        """Sets the bot_url of this UserAgentValidateResponse.

        Optional; if available, the URL to the robot  # noqa: E501

        :param bot_url: The bot_url of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._bot_url = bot_url

    @property
    def operating_system(self):
        """Gets the operating_system of this UserAgentValidateResponse.  # noqa: E501

        Operating System of the User-Agent (e.g. Windows)  # noqa: E501

        :return: The operating_system of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """Sets the operating_system of this UserAgentValidateResponse.

        Operating System of the User-Agent (e.g. Windows)  # noqa: E501

        :param operating_system: The operating_system of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._operating_system = operating_system

    @property
    def operating_system_cpu_platform(self):
        """Gets the operating_system_cpu_platform of this UserAgentValidateResponse.  # noqa: E501

        The CPU platform of the User-Agent (e.g. x64)  # noqa: E501

        :return: The operating_system_cpu_platform of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._operating_system_cpu_platform

    @operating_system_cpu_platform.setter
    def operating_system_cpu_platform(self, operating_system_cpu_platform):
        """Sets the operating_system_cpu_platform of this UserAgentValidateResponse.

        The CPU platform of the User-Agent (e.g. x64)  # noqa: E501

        :param operating_system_cpu_platform: The operating_system_cpu_platform of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._operating_system_cpu_platform = operating_system_cpu_platform

    @property
    def operating_system_version(self):
        """Gets the operating_system_version of this UserAgentValidateResponse.  # noqa: E501

        The version of the operating system of the User-Agent (e.g. \"10\" for Windows 10)  # noqa: E501

        :return: The operating_system_version of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._operating_system_version

    @operating_system_version.setter
    def operating_system_version(self, operating_system_version):
        """Sets the operating_system_version of this UserAgentValidateResponse.

        The version of the operating system of the User-Agent (e.g. \"10\" for Windows 10)  # noqa: E501

        :param operating_system_version: The operating_system_version of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._operating_system_version = operating_system_version

    @property
    def device_type(self):
        """Gets the device_type of this UserAgentValidateResponse.  # noqa: E501

        Device type of the User-Agent; possible values are \"DESKTOP\", \"SMARTPHONE\", \"TABLET\"  # noqa: E501

        :return: The device_type of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this UserAgentValidateResponse.

        Device type of the User-Agent; possible values are \"DESKTOP\", \"SMARTPHONE\", \"TABLET\"  # noqa: E501

        :param device_type: The device_type of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def device_brand_name(self):
        """Gets the device_brand_name of this UserAgentValidateResponse.  # noqa: E501

        Brand name of the User-Agent  # noqa: E501

        :return: The device_brand_name of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._device_brand_name

    @device_brand_name.setter
    def device_brand_name(self, device_brand_name):
        """Sets the device_brand_name of this UserAgentValidateResponse.

        Brand name of the User-Agent  # noqa: E501

        :param device_brand_name: The device_brand_name of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._device_brand_name = device_brand_name

    @property
    def device_model(self):
        """Gets the device_model of this UserAgentValidateResponse.  # noqa: E501

        Model name or number of the User-Agent  # noqa: E501

        :return: The device_model of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._device_model

    @device_model.setter
    def device_model(self, device_model):
        """Sets the device_model of this UserAgentValidateResponse.

        Model name or number of the User-Agent  # noqa: E501

        :param device_model: The device_model of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._device_model = device_model

    @property
    def browser_name(self):
        """Gets the browser_name of this UserAgentValidateResponse.  # noqa: E501

        Name of the Browser  # noqa: E501

        :return: The browser_name of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._browser_name

    @browser_name.setter
    def browser_name(self, browser_name):
        """Sets the browser_name of this UserAgentValidateResponse.

        Name of the Browser  # noqa: E501

        :param browser_name: The browser_name of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._browser_name = browser_name

    @property
    def browser_version(self):
        """Gets the browser_version of this UserAgentValidateResponse.  # noqa: E501

        Version of the Browser  # noqa: E501

        :return: The browser_version of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._browser_version

    @browser_version.setter
    def browser_version(self, browser_version):
        """Sets the browser_version of this UserAgentValidateResponse.

        Version of the Browser  # noqa: E501

        :param browser_version: The browser_version of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._browser_version = browser_version

    @property
    def browser_engine_name(self):
        """Gets the browser_engine_name of this UserAgentValidateResponse.  # noqa: E501

        Name of the Browser Engine  # noqa: E501

        :return: The browser_engine_name of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._browser_engine_name

    @browser_engine_name.setter
    def browser_engine_name(self, browser_engine_name):
        """Sets the browser_engine_name of this UserAgentValidateResponse.

        Name of the Browser Engine  # noqa: E501

        :param browser_engine_name: The browser_engine_name of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._browser_engine_name = browser_engine_name

    @property
    def browser_engine_version(self):
        """Gets the browser_engine_version of this UserAgentValidateResponse.  # noqa: E501

        Version of the Browser Engine  # noqa: E501

        :return: The browser_engine_version of this UserAgentValidateResponse.  # noqa: E501
        :rtype: str
        """
        return self._browser_engine_version

    @browser_engine_version.setter
    def browser_engine_version(self, browser_engine_version):
        """Sets the browser_engine_version of this UserAgentValidateResponse.

        Version of the Browser Engine  # noqa: E501

        :param browser_engine_version: The browser_engine_version of this UserAgentValidateResponse.  # noqa: E501
        :type: str
        """

        self._browser_engine_version = browser_engine_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserAgentValidateResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserAgentValidateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PhoneNumberValidateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'phone_number': 'str',
        'default_country_code': 'str'
    }

    attribute_map = {
        'phone_number': 'PhoneNumber',
        'default_country_code': 'DefaultCountryCode'
    }

    def __init__(self, phone_number=None, default_country_code=None):  # noqa: E501
        """PhoneNumberValidateRequest - a model defined in Swagger"""  # noqa: E501

        self._phone_number = None
        self._default_country_code = None
        self.discriminator = None

        if phone_number is not None:
            self.phone_number = phone_number
        if default_country_code is not None:
            self.default_country_code = default_country_code

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberValidateRequest.  # noqa: E501

        Raw phone number string to parse as input for validation  # noqa: E501

        :return: The phone_number of this PhoneNumberValidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberValidateRequest.

        Raw phone number string to parse as input for validation  # noqa: E501

        :param phone_number: The phone_number of this PhoneNumberValidateRequest.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def default_country_code(self):
        """Gets the default_country_code of this PhoneNumberValidateRequest.  # noqa: E501

        Optional, default country code.  If left blank, will default to \"US\".  # noqa: E501

        :return: The default_country_code of this PhoneNumberValidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._default_country_code

    @default_country_code.setter
    def default_country_code(self, default_country_code):
        """Sets the default_country_code of this PhoneNumberValidateRequest.

        Optional, default country code.  If left blank, will default to \"US\".  # noqa: E501

        :param default_country_code: The default_country_code of this PhoneNumberValidateRequest.  # noqa: E501
        :type: str
        """

        self._default_country_code = default_country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PhoneNumberValidateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberValidateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DateTimeStandardizedParseResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'parsed_date_result': 'datetime',
        'year': 'int',
        'month': 'int',
        'day': 'int',
        'hour': 'int',
        'minute': 'int',
        'second': 'int',
        'day_of_week': 'str'
    }

    attribute_map = {
        'successful': 'Successful',
        'parsed_date_result': 'ParsedDateResult',
        'year': 'Year',
        'month': 'Month',
        'day': 'Day',
        'hour': 'Hour',
        'minute': 'Minute',
        'second': 'Second',
        'day_of_week': 'DayOfWeek'
    }

    def __init__(self, successful=None, parsed_date_result=None, year=None, month=None, day=None, hour=None, minute=None, second=None, day_of_week=None):  # noqa: E501
        """DateTimeStandardizedParseResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._parsed_date_result = None
        self._year = None
        self._month = None
        self._day = None
        self._hour = None
        self._minute = None
        self._second = None
        self._day_of_week = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if parsed_date_result is not None:
            self.parsed_date_result = parsed_date_result
        if year is not None:
            self.year = year
        if month is not None:
            self.month = month
        if day is not None:
            self.day = day
        if hour is not None:
            self.hour = hour
        if minute is not None:
            self.minute = minute
        if second is not None:
            self.second = second
        if day_of_week is not None:
            self.day_of_week = day_of_week

    @property
    def successful(self):
        """Gets the successful of this DateTimeStandardizedParseResponse.  # noqa: E501

        True if successful, false otherwise  # noqa: E501

        :return: The successful of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this DateTimeStandardizedParseResponse.

        True if successful, false otherwise  # noqa: E501

        :param successful: The successful of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def parsed_date_result(self):
        """Gets the parsed_date_result of this DateTimeStandardizedParseResponse.  # noqa: E501

        Result of performing a date time parsing  # noqa: E501

        :return: The parsed_date_result of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._parsed_date_result

    @parsed_date_result.setter
    def parsed_date_result(self, parsed_date_result):
        """Sets the parsed_date_result of this DateTimeStandardizedParseResponse.

        Result of performing a date time parsing  # noqa: E501

        :param parsed_date_result: The parsed_date_result of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: datetime
        """

        self._parsed_date_result = parsed_date_result

    @property
    def year(self):
        """Gets the year of this DateTimeStandardizedParseResponse.  # noqa: E501

        Year of the parsed date time result  # noqa: E501

        :return: The year of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this DateTimeStandardizedParseResponse.

        Year of the parsed date time result  # noqa: E501

        :param year: The year of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def month(self):
        """Gets the month of this DateTimeStandardizedParseResponse.  # noqa: E501

        Month of the parsed date time result  # noqa: E501

        :return: The month of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: int
        """
        return self._month

    @month.setter
    def month(self, month):
        """Sets the month of this DateTimeStandardizedParseResponse.

        Month of the parsed date time result  # noqa: E501

        :param month: The month of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: int
        """

        self._month = month

    @property
    def day(self):
        """Gets the day of this DateTimeStandardizedParseResponse.  # noqa: E501

        Day of the parsed date time result  # noqa: E501

        :return: The day of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: int
        """
        return self._day

    @day.setter
    def day(self, day):
        """Sets the day of this DateTimeStandardizedParseResponse.

        Day of the parsed date time result  # noqa: E501

        :param day: The day of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: int
        """

        self._day = day

    @property
    def hour(self):
        """Gets the hour of this DateTimeStandardizedParseResponse.  # noqa: E501

        Hour of the parsed date time result (24-hour)  # noqa: E501

        :return: The hour of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: int
        """
        return self._hour

    @hour.setter
    def hour(self, hour):
        """Sets the hour of this DateTimeStandardizedParseResponse.

        Hour of the parsed date time result (24-hour)  # noqa: E501

        :param hour: The hour of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: int
        """

        self._hour = hour

    @property
    def minute(self):
        """Gets the minute of this DateTimeStandardizedParseResponse.  # noqa: E501

        Minute of the parsed date time result  # noqa: E501

        :return: The minute of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: int
        """
        return self._minute

    @minute.setter
    def minute(self, minute):
        """Sets the minute of this DateTimeStandardizedParseResponse.

        Minute of the parsed date time result  # noqa: E501

        :param minute: The minute of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: int
        """

        self._minute = minute

    @property
    def second(self):
        """Gets the second of this DateTimeStandardizedParseResponse.  # noqa: E501

        Second of the parsed date time result  # noqa: E501

        :return: The second of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: int
        """
        return self._second

    @second.setter
    def second(self, second):
        """Sets the second of this DateTimeStandardizedParseResponse.

        Second of the parsed date time result  # noqa: E501

        :param second: The second of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: int
        """

        self._second = second

    @property
    def day_of_week(self):
        """Gets the day_of_week of this DateTimeStandardizedParseResponse.  # noqa: E501

        Day of week  # noqa: E501

        :return: The day_of_week of this DateTimeStandardizedParseResponse.  # noqa: E501
        :rtype: str
        """
        return self._day_of_week

    @day_of_week.setter
    def day_of_week(self, day_of_week):
        """Sets the day_of_week of this DateTimeStandardizedParseResponse.

        Day of week  # noqa: E501

        :param day_of_week: The day_of_week of this DateTimeStandardizedParseResponse.  # noqa: E501
        :type: str
        """

        self._day_of_week = day_of_week

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DateTimeStandardizedParseResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DateTimeStandardizedParseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ValidateUrlResponseFull(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'valid_url': 'bool',
        'valid_syntax': 'bool',
        'valid_domain': 'bool',
        'valid_endpoint': 'bool',
        'well_formed_url': 'str'
    }

    attribute_map = {
        'valid_url': 'ValidURL',
        'valid_syntax': 'Valid_Syntax',
        'valid_domain': 'Valid_Domain',
        'valid_endpoint': 'Valid_Endpoint',
        'well_formed_url': 'WellFormedURL'
    }

    def __init__(self, valid_url=None, valid_syntax=None, valid_domain=None, valid_endpoint=None, well_formed_url=None):  # noqa: E501
        """ValidateUrlResponseFull - a model defined in Swagger"""  # noqa: E501

        self._valid_url = None
        self._valid_syntax = None
        self._valid_domain = None
        self._valid_endpoint = None
        self._well_formed_url = None
        self.discriminator = None

        if valid_url is not None:
            self.valid_url = valid_url
        if valid_syntax is not None:
            self.valid_syntax = valid_syntax
        if valid_domain is not None:
            self.valid_domain = valid_domain
        if valid_endpoint is not None:
            self.valid_endpoint = valid_endpoint
        if well_formed_url is not None:
            self.well_formed_url = well_formed_url

    @property
    def valid_url(self):
        """Gets the valid_url of this ValidateUrlResponseFull.  # noqa: E501

        True if the URL has valid syntax, a valid domain, a valid endpoint, and passes virus scan checks; false otherwise  # noqa: E501

        :return: The valid_url of this ValidateUrlResponseFull.  # noqa: E501
        :rtype: bool
        """
        return self._valid_url

    @valid_url.setter
    def valid_url(self, valid_url):
        """Sets the valid_url of this ValidateUrlResponseFull.

        True if the URL has valid syntax, a valid domain, a valid endpoint, and passes virus scan checks; false otherwise  # noqa: E501

        :param valid_url: The valid_url of this ValidateUrlResponseFull.  # noqa: E501
        :type: bool
        """

        self._valid_url = valid_url

    @property
    def valid_syntax(self):
        """Gets the valid_syntax of this ValidateUrlResponseFull.  # noqa: E501

        True if the URL has valid syntax, false otherwise  # noqa: E501

        :return: The valid_syntax of this ValidateUrlResponseFull.  # noqa: E501
        :rtype: bool
        """
        return self._valid_syntax

    @valid_syntax.setter
    def valid_syntax(self, valid_syntax):
        """Sets the valid_syntax of this ValidateUrlResponseFull.

        True if the URL has valid syntax, false otherwise  # noqa: E501

        :param valid_syntax: The valid_syntax of this ValidateUrlResponseFull.  # noqa: E501
        :type: bool
        """

        self._valid_syntax = valid_syntax

    @property
    def valid_domain(self):
        """Gets the valid_domain of this ValidateUrlResponseFull.  # noqa: E501

        True if the domain name is valid and exists, false otherwise  # noqa: E501

        :return: The valid_domain of this ValidateUrlResponseFull.  # noqa: E501
        :rtype: bool
        """
        return self._valid_domain

    @valid_domain.setter
    def valid_domain(self, valid_domain):
        """Sets the valid_domain of this ValidateUrlResponseFull.

        True if the domain name is valid and exists, false otherwise  # noqa: E501

        :param valid_domain: The valid_domain of this ValidateUrlResponseFull.  # noqa: E501
        :type: bool
        """

        self._valid_domain = valid_domain

    @property
    def valid_endpoint(self):
        """Gets the valid_endpoint of this ValidateUrlResponseFull.  # noqa: E501

        True if the endpoint is up and responsive and passes a virus scan check, false otherwise  # noqa: E501

        :return: The valid_endpoint of this ValidateUrlResponseFull.  # noqa: E501
        :rtype: bool
        """
        return self._valid_endpoint

    @valid_endpoint.setter
    def valid_endpoint(self, valid_endpoint):
        """Sets the valid_endpoint of this ValidateUrlResponseFull.

        True if the endpoint is up and responsive and passes a virus scan check, false otherwise  # noqa: E501

        :param valid_endpoint: The valid_endpoint of this ValidateUrlResponseFull.  # noqa: E501
        :type: bool
        """

        self._valid_endpoint = valid_endpoint

    @property
    def well_formed_url(self):
        """Gets the well_formed_url of this ValidateUrlResponseFull.  # noqa: E501

        Well-formed version of the URL  # noqa: E501

        :return: The well_formed_url of this ValidateUrlResponseFull.  # noqa: E501
        :rtype: str
        """
        return self._well_formed_url

    @well_formed_url.setter
    def well_formed_url(self, well_formed_url):
        """Sets the well_formed_url of this ValidateUrlResponseFull.

        Well-formed version of the URL  # noqa: E501

        :param well_formed_url: The well_formed_url of this ValidateUrlResponseFull.  # noqa: E501
        :type: str
        """

        self._well_formed_url = well_formed_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidateUrlResponseFull, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidateUrlResponseFull):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PhoneNumberValidationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_valid': 'bool',
        'successful': 'bool',
        'phone_number_type': 'str',
        'e164_format': 'str',
        'international_format': 'str',
        'national_format': 'str',
        'country_code': 'str',
        'country_name': 'str'
    }

    attribute_map = {
        'is_valid': 'IsValid',
        'successful': 'Successful',
        'phone_number_type': 'PhoneNumberType',
        'e164_format': 'E164Format',
        'international_format': 'InternationalFormat',
        'national_format': 'NationalFormat',
        'country_code': 'CountryCode',
        'country_name': 'CountryName'
    }

    def __init__(self, is_valid=None, successful=None, phone_number_type=None, e164_format=None, international_format=None, national_format=None, country_code=None, country_name=None):  # noqa: E501
        """PhoneNumberValidationResponse - a model defined in Swagger"""  # noqa: E501

        self._is_valid = None
        self._successful = None
        self._phone_number_type = None
        self._e164_format = None
        self._international_format = None
        self._national_format = None
        self._country_code = None
        self._country_name = None
        self.discriminator = None

        if is_valid is not None:
            self.is_valid = is_valid
        if successful is not None:
            self.successful = successful
        if phone_number_type is not None:
            self.phone_number_type = phone_number_type
        if e164_format is not None:
            self.e164_format = e164_format
        if international_format is not None:
            self.international_format = international_format
        if national_format is not None:
            self.national_format = national_format
        if country_code is not None:
            self.country_code = country_code
        if country_name is not None:
            self.country_name = country_name

    @property
    def is_valid(self):
        """Gets the is_valid of this PhoneNumberValidationResponse.  # noqa: E501

        True if the phone number is valid, false otherwise  # noqa: E501

        :return: The is_valid of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this PhoneNumberValidationResponse.

        True if the phone number is valid, false otherwise  # noqa: E501

        :param is_valid: The is_valid of this PhoneNumberValidationResponse.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def successful(self):
        """Gets the successful of this PhoneNumberValidationResponse.  # noqa: E501

        True if the operation was successful, false if there was an error during validation.  See IsValid for validation result.  # noqa: E501

        :return: The successful of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this PhoneNumberValidationResponse.

        True if the operation was successful, false if there was an error during validation.  See IsValid for validation result.  # noqa: E501

        :param successful: The successful of this PhoneNumberValidationResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def phone_number_type(self):
        """Gets the phone_number_type of this PhoneNumberValidationResponse.  # noqa: E501

        Type of phone number; possible values are: FixedLine, Mobile, FixedLineOrMobile, TollFree, PremiumRate,   SharedCost, Voip, PersonalNumber, Pager, Uan, Voicemail, Unknown  # noqa: E501

        :return: The phone_number_type of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """Sets the phone_number_type of this PhoneNumberValidationResponse.

        Type of phone number; possible values are: FixedLine, Mobile, FixedLineOrMobile, TollFree, PremiumRate,   SharedCost, Voip, PersonalNumber, Pager, Uan, Voicemail, Unknown  # noqa: E501

        :param phone_number_type: The phone_number_type of this PhoneNumberValidationResponse.  # noqa: E501
        :type: str
        """

        self._phone_number_type = phone_number_type

    @property
    def e164_format(self):
        """Gets the e164_format of this PhoneNumberValidationResponse.  # noqa: E501

        E.164 format of the phone number  # noqa: E501

        :return: The e164_format of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._e164_format

    @e164_format.setter
    def e164_format(self, e164_format):
        """Sets the e164_format of this PhoneNumberValidationResponse.

        E.164 format of the phone number  # noqa: E501

        :param e164_format: The e164_format of this PhoneNumberValidationResponse.  # noqa: E501
        :type: str
        """

        self._e164_format = e164_format

    @property
    def international_format(self):
        """Gets the international_format of this PhoneNumberValidationResponse.  # noqa: E501

        Internaltional format of the phone number  # noqa: E501

        :return: The international_format of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._international_format

    @international_format.setter
    def international_format(self, international_format):
        """Sets the international_format of this PhoneNumberValidationResponse.

        Internaltional format of the phone number  # noqa: E501

        :param international_format: The international_format of this PhoneNumberValidationResponse.  # noqa: E501
        :type: str
        """

        self._international_format = international_format

    @property
    def national_format(self):
        """Gets the national_format of this PhoneNumberValidationResponse.  # noqa: E501

        National format of the phone number  # noqa: E501

        :return: The national_format of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._national_format

    @national_format.setter
    def national_format(self, national_format):
        """Sets the national_format of this PhoneNumberValidationResponse.

        National format of the phone number  # noqa: E501

        :param national_format: The national_format of this PhoneNumberValidationResponse.  # noqa: E501
        :type: str
        """

        self._national_format = national_format

    @property
    def country_code(self):
        """Gets the country_code of this PhoneNumberValidationResponse.  # noqa: E501

        Two digit country code of the phone number  # noqa: E501

        :return: The country_code of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this PhoneNumberValidationResponse.

        Two digit country code of the phone number  # noqa: E501

        :param country_code: The country_code of this PhoneNumberValidationResponse.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def country_name(self):
        """Gets the country_name of this PhoneNumberValidationResponse.  # noqa: E501

        User-friendly long name of the country for the phone number  # noqa: E501

        :return: The country_name of this PhoneNumberValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._country_name

    @country_name.setter
    def country_name(self, country_name):
        """Sets the country_name of this PhoneNumberValidationResponse.

        User-friendly long name of the country for the phone number  # noqa: E501

        :param country_name: The country_name of this PhoneNumberValidationResponse.  # noqa: E501
        :type: str
        """

        self._country_name = country_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PhoneNumberValidationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberValidationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
